import { Component, Input, Output, HostBinding, HostListener, EventEmitter, Renderer2, ElementRef, ChangeDetectorRef } from "@angular/core";
import { TransitionController, SuiTransition, TransitionDirection, Transition } from "../../transition";
var SuiDimmer = (function (_super) {
    __extends(SuiDimmer, _super);
    function SuiDimmer(renderer, element, changeDetector) {
        var _this = _super.call(this, renderer, element, changeDetector) || this;
        _this._isDimmed = false;
        _this.isDimmedChange = new EventEmitter();
        _this.isClickable = true;
        _this._dimmerClasses = true;
        return _this;
    }
    Object.defineProperty(SuiDimmer.prototype, "isDimmed", {
        get: function () {
            return this._isDimmed;
        },
        set: function (value) {
            var isDimmed = !!value;
            if (!this._transitionController) {
                // Initialise transition functionality when first setting dimmed, to ensure initial state doesn't transition.
                this._transitionController = new TransitionController(isDimmed, "block");
                this.setTransitionController(this._transitionController);
            }
            if (this._isDimmed !== isDimmed) {
                this._isDimmed = isDimmed;
                if (this._transitionController.isVisible !== isDimmed) {
                    this._transitionController.stopAll();
                    this._transitionController.animate(new Transition("fade", this.transitionDuration, isDimmed ? TransitionDirection.In : TransitionDirection.Out));
                }
            }
        },
        enumerable: true,
        configurable: true
    });
    SuiDimmer.prototype.onClick = function () {
        if (this.isClickable) {
            this.isDimmed = false;
            this.isDimmedChange.emit(this.isDimmed);
        }
    };
    return SuiDimmer;
}(SuiTransition));
__decorate([
    HostBinding("class.ui"),
    HostBinding("class.dimmer"),
    __metadata("design:type", Boolean)
], SuiDimmer.prototype, "_dimmerClasses", void 0);
__decorate([
    HostBinding("class.active"),
    Input(),
    __metadata("design:type", Boolean),
    __metadata("design:paramtypes", [Boolean])
], SuiDimmer.prototype, "isDimmed", null);
__decorate([
    Output(),
    __metadata("design:type", EventEmitter)
], SuiDimmer.prototype, "isDimmedChange", void 0);
__decorate([
    Input(),
    __metadata("design:type", Boolean)
], SuiDimmer.prototype, "isClickable", void 0);
__decorate([
    Input(),
    __metadata("design:type", String)
], SuiDimmer.prototype, "transition", void 0);
__decorate([
    Input(),
    __metadata("design:type", Number)
], SuiDimmer.prototype, "transitionDuration", void 0);
__decorate([
    HostListener("click"),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], SuiDimmer.prototype, "onClick", null);
SuiDimmer = __decorate([
    Component({
        selector: "sui-dimmer",
        template: "\n<div class=\"content\">\n    <div class=\"center\">\n        <ng-content></ng-content>\n    </div>\n</div>\n",
        styles: ["\n:host.dimmer {\n    transition: none;\n}\n"]
    }),
    __metadata("design:paramtypes", [Renderer2, ElementRef, ChangeDetectorRef])
], SuiDimmer);
export { SuiDimmer };
//# sourceMappingURL=dimmer.js.map